@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-import logging
 import os
 import subprocess
 import sys
@@ -19,7 +18,10 @@ from semantic_release.cli.changelog_writer import (
     generate_release_notes,
     write_changelog_files,
 )
-from semantic_release.cli.github_actions_output import VersionGitHubActionsOutput
+from semantic_release.cli.github_actions_output import (
+    PersistenceMode,
+    VersionGitHubActionsOutput,
+)
 from semantic_release.cli.util import noop_report, rprint
 from semantic_release.const import DEFAULT_SHELL, DEFAULT_VERSION
 from semantic_release.enums import LevelBump
@@ -30,6 +32,8 @@ from semantic_release.errors import (
     UnexpectedResponse,
 )
 from semantic_release.gitproject import GitProject
+from semantic_release.globals import logger
+from semantic_release.hvcs.github import Github
 from semantic_release.hvcs.remote_hvcs_base import RemoteHvcsBase
 from semantic_release.version.algorithm import (
     next_version,
@@ -48,9 +52,6 @@ if TYPE_CHECKING:  # pragma: no cover
     from semantic_release.version.version import Version
 
 
-log = logging.getLogger(__name__)
-
-
 def is_forced_prerelease(
     as_prerelease: bool, forced_level_bump: LevelBump | None, prerelease: bool
 ) -> bool:
@@ -62,7 +63,7 @@ def is_forced_prerelease(
     Otherwise (``force_level is None``) use the value of ``prerelease``
     """
     local_vars = list(locals().items())
-    log.debug(
+    logger.debug(
         "%s: %s",
         is_forced_prerelease.__name__,
         str.join(", ", iter(f"{k} = {v}" for k, v in local_vars)),
@@ -143,16 +144,12 @@ def apply_version_to_source_files(
         return []
 
     if not noop:
-        log.debug("Updating version %s in repository files...", version)
+        logger.debug("Updating version %s in repository files...", version)
 
-    paths = list(
-        map(
-            lambda decl, new_version=version, noop=noop: (  # type: ignore[misc]
-                decl.update_file_w_version(new_version=new_version, noop=noop)
-            ),
-            version_declarations,
-        )
-    )
+    paths = [
+        decl.update_file_w_version(new_version=version, noop=noop)
+        for decl in version_declarations
+    ]
 
     repo_filepaths = [
         str(updated_file.relative_to(repo_dir))
@@ -181,8 +178,8 @@ def shell(
     try:
         shell, _ = shellingham.detect_shell()
     except shellingham.ShellDetectionFailure:
-        log.warning("failed to detect shell, using default shell: %s", DEFAULT_SHELL)
-        log.debug("stack trace", exc_info=True)
+        logger.warning("failed to detect shell, using default shell: %s", DEFAULT_SHELL)
+        logger.debug("stack trace", exc_info=True)
         shell = DEFAULT_SHELL
 
     if not shell:
@@ -231,6 +228,7 @@ def get_windows_env() -> Mapping[str, str | None]:
             "SYSTEMROOT",
             "TEMP",
             "TMP",
+            "USERNAME",  # must include for python getpass.getuser() on windows
             "USERPROFILE",
             "USERSID",
             "WINDIR",
@@ -261,7 +259,7 @@ def build_distributions(
         noop_report(f"would have run the build_command {build_command}")
         return
 
-    log.info("Running build command %s", build_command)
+    logger.info("Running build command %s", build_command)
     rprint(f"[bold green]:hammer_and_wrench: Running build command: {build_command}")
 
     build_env_vars: dict[str, str] = dict(
@@ -295,8 +293,8 @@ def build_distributions(
         shell(build_command, env=build_env_vars, check=True)
         rprint("[bold green]Build completed successfully!")
     except subprocess.CalledProcessError as exc:
-        log.exception(exc)
-        log.error("Build command failed with exit code %s", exc.returncode)  # noqa: TRY400
+        logger.exception(exc)
+        logger.error("Build command failed with exit code %s", exc.returncode)  # noqa: TRY400
         raise BuildDistributionsError from exc
 
 
@@ -453,7 +451,7 @@ def version(  # noqa: C901
         if not (
             last_release := last_released(config.repo_dir, tag_format=config.tag_format)
         ):
-            log.warning("No release tags found.")
+            logger.warning("No release tags found.")
             return
 
         click.echo(last_release[0] if print_last_released_tag else last_release[1])
@@ -472,7 +470,19 @@ def version(  # noqa: C901
     major_on_zero = runtime.major_on_zero
     no_verify = runtime.no_git_verify
     opts = runtime.global_cli_options
-    gha_output = VersionGitHubActionsOutput(released=False)
+    gha_output = VersionGitHubActionsOutput(
+        gh_client=(
+            hvcs_client
+            if isinstance(hvcs_client, Github)
+            else Github(hvcs_client.remote_url(use_token=False))
+        ),
+        mode=(
+            PersistenceMode.TEMPORARY
+            if opts.noop or (not commit_changes and not create_tag)
+            else PersistenceMode.PERMANENT
+        ),
+        released=False,
+    )
 
     forced_level_bump = None if not force_level else LevelBump.from_string(force_level)
     prerelease = is_forced_prerelease(
@@ -482,22 +492,24 @@ def version(  # noqa: C901
     )
 
     if prerelease_token:
-        log.info("Forcing use of %s as the prerelease token", prerelease_token)
+        logger.info("Forcing use of %s as the prerelease token", prerelease_token)
         translator.prerelease_token = prerelease_token
 
     # Only push if we're committing changes
     if push_changes and not commit_changes and not create_tag:
-        log.info("changes will not be pushed because --no-commit disables pushing")
+        logger.info("changes will not be pushed because --no-commit disables pushing")
         push_changes &= commit_changes
 
     # Only push if we're creating a tag
     if push_changes and not create_tag and not commit_changes:
-        log.info("new tag will not be pushed because --no-tag disables pushing")
+        logger.info("new tag will not be pushed because --no-tag disables pushing")
         push_changes &= create_tag
 
     # Only make a release if we're pushing the changes
     if make_vcs_release and not push_changes:
-        log.info("No vcs release will be created because pushing changes is disabled")
+        logger.info(
+            "No vcs release will be created because pushing changes is disabled"
+        )
         make_vcs_release &= push_changes
 
     if not forced_level_bump:
@@ -511,7 +523,7 @@ def version(  # noqa: C901
                 allow_zero_version=runtime.allow_zero_version,
             )
     else:
-        log.warning(
+        logger.warning(
             "Forcing a '%s' release due to '--%s' command-line flag",
             force_level,
             (
@@ -576,6 +588,12 @@ def version(  # noqa: C901
     if print_only or print_only_tag:
         return
 
+    # TODO: need a better way as this is inconsistent if releasing older version patches
+    if last_release := last_released(config.repo_dir, tag_format=config.tag_format):
+        # If we have a last release, we can set the previous version for the
+        # GitHub Actions output
+        gha_output.prev_version = last_release[1]
+
     with Repo(str(runtime.repo_dir)) as git_repo:
         release_history = ReleaseHistory.from_git_history(
             repo=git_repo,
@@ -636,6 +654,7 @@ def version(  # noqa: C901
                     **runtime.build_command_env,
                     # PSR injected environment variables
                     "NEW_VERSION": str(new_version),
+                    "PACKAGE_NAME": runtime.project_metadata.get("name", ""),
                 },
                 noop=opts.noop,
             )
@@ -644,16 +663,38 @@ def version(  # noqa: C901
             click.echo("Build failed, aborting release", err=True)
             ctx.exit(1)
 
+    license_cfg = runtime.project_metadata.get(
+        "license-expression",
+        runtime.project_metadata.get(
+            "license",
+            "",
+        ),
+    )
+
+    license_cfg = "" if not isinstance(license_cfg, (str, dict)) else license_cfg
+    license_cfg = (
+        license_cfg.get("text", "") if isinstance(license_cfg, dict) else license_cfg
+    )
+
+    gha_output.release_notes = release_notes = generate_release_notes(
+        hvcs_client,
+        release=release_history.released[new_version],
+        template_dir=runtime.template_dir,
+        history=release_history,
+        style=runtime.changelog_style,
+        mask_initial_release=runtime.changelog_mask_initial_release,
+        license_name="" if not isinstance(license_cfg, str) else license_cfg,
+    )
+
     project = GitProject(
         directory=runtime.repo_dir,
         commit_author=runtime.commit_author,
         credential_masker=runtime.masker,
     )
 
-    # Preparing for committing changes
+    # Preparing for committing changes; we always stage files even if we're not committing them in order to support a two-stage commit
+    project.git_add(paths=all_paths_to_add, noop=opts.noop)
     if commit_changes:
-        project.git_add(paths=all_paths_to_add, noop=opts.noop)
-
         # NOTE: If we haven't modified any source code then we skip trying to make a commit
         # and any tag that we apply will be to the HEAD commit (made outside of
         # running PSR
@@ -665,7 +706,7 @@ def version(  # noqa: C901
                 noop=opts.noop,
             )
         except GitCommitEmptyIndexError:
-            log.info("No local changes to add to any commit, skipping")
+            logger.info("No local changes to add to any commit, skipping")
 
     # Tag the version after potentially creating a new HEAD commit.
     # This way if no source code is modified, i.e. all metadata updates
@@ -680,6 +721,9 @@ def version(  # noqa: C901
             noop=opts.noop,
         )
 
+        with Repo(str(runtime.repo_dir)) as git_repo:
+            gha_output.commit_sha = git_repo.head.commit.hexsha
+
     if push_changes:
         remote_url = runtime.hvcs_client.remote_url(
             use_token=not runtime.ignore_token_for_push
@@ -711,36 +755,9 @@ def version(  # noqa: C901
         return
 
     if not isinstance(hvcs_client, RemoteHvcsBase):
-        log.info("Remote does not support releases. Skipping release creation...")
+        logger.info("Remote does not support releases. Skipping release creation...")
         return
 
-    license_cfg = runtime.project_metadata.get(
-        "license-expression",
-        runtime.project_metadata.get(
-            "license",
-            "",
-        ),
-    )
-
-    if not isinstance(license_cfg, (str, dict)) or license_cfg is None:
-        license_cfg = ""
-
-    license_name = (
-        license_cfg.get("text", "")
-        if isinstance(license_cfg, dict)
-        else license_cfg or ""
-    )
-
-    release_notes = generate_release_notes(
-        hvcs_client,
-        release=release_history.released[new_version],
-        template_dir=runtime.template_dir,
-        history=release_history,
-        style=runtime.changelog_style,
-        mask_initial_release=runtime.changelog_mask_initial_release,
-        license_name=license_name,
-    )
-
     exception: Exception | None = None
     help_message = ""
     try:
@@ -774,7 +791,7 @@ def version(  # noqa: C901
         exception = err
     finally:
         if exception is not None:
-            log.exception(exception)
+            logger.exception(exception)
             click.echo(str(exception), err=True)
             if help_message:
                 click.echo(help_message, err=True)
