@@ -11,6 +11,7 @@ from semantic_release.commit_parser.token import ParseError
 from semantic_release.const import DEFAULT_VERSION
 from semantic_release.enums import LevelBump, SemanticReleaseLogLevels
 from semantic_release.errors import InternalError, InvalidVersion
+from semantic_release.globals import logger
 from semantic_release.helpers import validate_types_in_sequence
 
 if TYPE_CHECKING:  # pragma: no cover
@@ -29,9 +30,6 @@ if TYPE_CHECKING:  # pragma: no cover
     from semantic_release.version.version import Version
 
 
-logger = logging.getLogger(__name__)
-
-
 def tags_and_versions(
     tags: Iterable[Tag], translator: VersionTranslator
 ) -> list[tuple[Tag, Version]]:
@@ -247,9 +245,9 @@ def next_version(
     repo: Repo,
     translator: VersionTranslator,
     commit_parser: CommitParser[ParseResult, ParserOptions],
+    allow_zero_version: bool,
+    major_on_zero: bool,
     prerelease: bool = False,
-    major_on_zero: bool = True,
-    allow_zero_version: bool = True,
 ) -> Version:
     """
     Evaluate the history within `repo`, and based on the tags and commits in the repo
