@@ -7,28 +7,26 @@ import tomlkit
 from flatdict import FlatDict
 from freezegun import freeze_time
 
-from semantic_release.cli.commands.main import main
-
 from tests.const import (
     DEFAULT_BRANCH_NAME,
-    MAIN_PROG_NAME,
-    VERSION_SUBCMD,
 )
 from tests.fixtures.repos.trunk_based_dev import (
     repo_w_trunk_only_dual_version_spt_conventional_commits,
     repo_w_trunk_only_dual_version_spt_emoji_commits,
     repo_w_trunk_only_dual_version_spt_scipy_commits,
 )
-from tests.util import assert_successful_exit_code, temporary_working_directory
+from tests.util import temporary_working_directory
 
 if TYPE_CHECKING:
     from pathlib import Path
     from unittest.mock import MagicMock
 
-    from click.testing import CliRunner
     from requests_mock import Mocker
 
-    from tests.e2e.cmd_version.bump_version.conftest import InitMirrorRepo4RebuildFn
+    from tests.e2e.cmd_version.bump_version.conftest import (
+        InitMirrorRepo4RebuildFn,
+        RunPSReleaseFn,
+    )
     from tests.e2e.conftest import GetSanitizedChangelogContentFn
     from tests.fixtures.example_project import ExProjectDir
     from tests.fixtures.git_repo import (
@@ -56,7 +54,7 @@ if TYPE_CHECKING:
 )
 def test_trunk_repo_rebuild_dual_version_spt_official_releases_only(
     repo_fixture_name: str,
-    cli_runner: CliRunner,
+    run_psr_release: RunPSReleaseFn,
     build_trunk_only_repo_w_dual_version_support: BuildSpecificRepoFn,
     split_repo_actions_by_release_tags: SplitRepoActionsByReleaseTagsFn,
     init_mirror_repo_for_rebuild: InitMirrorRepo4RebuildFn,
@@ -139,19 +137,10 @@ def test_trunk_repo_rebuild_dual_version_spt_official_releases_only(
         with freeze_time(
             release_action_step["details"]["datetime"]
         ), temporary_working_directory(mirror_repo_dir):
-            build_metadata_args = (
-                [
-                    "--build-metadata",
-                    release_action_step["details"]["version"].split("+", maxsplit=1)[
-                        -1
-                    ],
-                ]
-                if len(release_action_step["details"]["version"].split("+", maxsplit=1))
-                > 1
-                else []
+            run_psr_release(
+                next_version_str=release_action_step["details"]["version"],
+                git_repo=mirror_git_repo,
             )
-            cli_cmd = [MAIN_PROG_NAME, "--strict", VERSION_SUBCMD, *build_metadata_args]
-            result = cli_runner.invoke(main, cli_cmd[1:])
 
         # take measurement after running the version command
         actual_release_commit_text = mirror_git_repo.head.commit.message
@@ -165,7 +154,7 @@ def test_trunk_repo_rebuild_dual_version_spt_official_releases_only(
         )
 
         # Evaluate (normal release actions should have occurred as expected)
-        assert_successful_exit_code(result, cli_cmd)
+        # ------------------------------------------------------------------
         # Make sure version file is updated
         assert expected_pyproject_toml_content == actual_pyproject_toml_content
         assert expected_version_file_content == actual_version_file_content
