@@ -9,7 +9,6 @@ from freezegun import freeze_time
 from pytest_lazy_fixtures.lazy_fixture import lf as lazy_fixture
 
 from semantic_release.changelog.context import ChangelogMode
-from semantic_release.cli.commands.main import main
 from semantic_release.cli.config import ChangelogOutputFormat
 
 from tests.const import MAIN_PROG_NAME, VERSION_SUBCMD
@@ -34,6 +33,7 @@ from tests.fixtures.repos import (
     repo_w_github_flow_w_feature_release_channel_emoji_commits,
     repo_w_github_flow_w_feature_release_channel_scipy_commits,
     repo_w_no_tags_conventional_commits,
+    repo_w_no_tags_conventional_commits_unmasked_initial_release,
     repo_w_no_tags_emoji_commits,
     repo_w_no_tags_scipy_commits,
     repo_w_trunk_only_conventional_commits,
@@ -48,9 +48,7 @@ from tests.util import assert_successful_exit_code
 if TYPE_CHECKING:
     from pathlib import Path
 
-    from click.testing import CliRunner
-
-    from tests.conftest import FormatDateStrFn, GetStableDateNowFn
+    from tests.conftest import FormatDateStrFn, GetStableDateNowFn, RunCliFn
     from tests.fixtures.example_project import UpdatePyprojectTomlFn
     from tests.fixtures.git_repo import (
         BuiltRepoResult,
@@ -176,7 +174,7 @@ def test_version_updates_changelog_w_new_version(
     get_versions_from_repo_build_def: GetVersionsFromRepoBuildDefFn,
     tag_format: str,
     update_pyproject_toml: UpdatePyprojectTomlFn,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     changelog_file: Path,
     insertion_flag: str,
     cache: pytest.Cache,
@@ -255,7 +253,7 @@ def test_version_updates_changelog_w_new_version(
 
     with freeze_time(now_datetime.astimezone(timezone.utc)):
         cli_cmd = [MAIN_PROG_NAME, VERSION_SUBCMD, "--no-push", "--changelog"]
-        result = cli_runner.invoke(main, cli_cmd[1:])
+        result = run_cli(cli_cmd[1:])
 
     # Capture the new changelog content (os aware because of expected content)
     with changelog_file.open(newline=os.linesep) as rfd:
@@ -307,7 +305,152 @@ def test_version_updates_changelog_wo_prev_releases(
     repo_result: BuiltRepoResult,
     cache_key: str,
     cache: pytest.Cache,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
+    update_pyproject_toml: UpdatePyprojectTomlFn,
+    changelog_format: ChangelogOutputFormat,
+    changelog_file: Path,
+    insertion_flag: str,
+    stable_now_date: GetStableDateNowFn,
+    format_date_str: FormatDateStrFn,
+):
+    """
+    Given the repository has no releases and the user has provided a initialized changelog,
+    When the version command is run with changelog.mode set to "update",
+    Then the version is created and the changelog file is updated with only an initial release statement
+    """
+    if not (repo_build_data := cache.get(cache_key, None)):
+        pytest.fail("Repo build date not found in cache")
+
+    repo_build_datetime = datetime.strptime(repo_build_data["build_date"], "%Y-%m-%d")
+    now_datetime = stable_now_date().replace(
+        year=repo_build_datetime.year,
+        month=repo_build_datetime.month,
+        day=repo_build_datetime.day,
+    )
+    repo_build_date_str = format_date_str(now_datetime)
+
+    # Custom text to maintain (must be different from the default)
+    custom_text = "---{ls}{ls}Custom footer text{ls}".format(ls=os.linesep)
+
+    # Set the project configurations
+    update_pyproject_toml(
+        "tool.semantic_release.changelog.mode", ChangelogMode.UPDATE.value
+    )
+    update_pyproject_toml(
+        "tool.semantic_release.changelog.default_templates.changelog_file",
+        str(changelog_file.name),
+    )
+
+    version = "v1.0.0"
+    rst_version_header = f"{version} ({repo_build_date_str})"
+    txt_after_insertion_flag = {
+        ChangelogOutputFormat.MARKDOWN: str.join(
+            os.linesep,
+            [
+                f"## {version} ({repo_build_date_str})",
+                "",
+                "- Initial Release",
+            ],
+        ),
+        ChangelogOutputFormat.RESTRUCTURED_TEXT: str.join(
+            os.linesep,
+            [
+                f".. _changelog-{version}:",
+                "",
+                rst_version_header,
+                f"{'=' * len(rst_version_header)}",
+                "",
+                "* Initial Release",
+            ],
+        ),
+    }
+
+    # Capture and modify the current changelog content to become the expected output
+    # We much use os.linesep here since the insertion flag is os-specific
+    with changelog_file.open(newline=os.linesep) as rfd:
+        initial_changelog_parts = rfd.read().split(insertion_flag)
+
+    # content is os-specific because of the insertion flag & how we read the original file
+    expected_changelog_content = str.join(
+        insertion_flag,
+        [
+            initial_changelog_parts[0],
+            str.join(
+                os.linesep,
+                [
+                    os.linesep,
+                    txt_after_insertion_flag[changelog_format],
+                    "",
+                    custom_text,
+                ],
+            ),
+        ],
+    )
+
+    # Grab the Unreleased changelog & create the initialized user changelog
+    # force output to not perform any newline translations
+    with changelog_file.open(mode="w", newline="") as wfd:
+        wfd.write(
+            str.join(
+                insertion_flag,
+                [initial_changelog_parts[0], f"{os.linesep * 2}{custom_text}"],
+            )
+        )
+        wfd.flush()
+
+    # Act
+    with freeze_time(now_datetime.astimezone(timezone.utc)):
+        cli_cmd = [MAIN_PROG_NAME, VERSION_SUBCMD, "--no-push", "--changelog"]
+        result = run_cli(cli_cmd[1:])
+
+    # Evaluate
+    assert_successful_exit_code(result, cli_cmd)
+
+    # Ensure changelog exists
+    assert changelog_file.exists()
+
+    # Capture the new changelog content (os aware because of expected content)
+    with changelog_file.open(newline=os.linesep) as rfd:
+        actual_content = rfd.read()
+
+    # Check that the changelog footer is maintained and updated with Unreleased info
+    assert expected_changelog_content == actual_content
+
+
+@pytest.mark.parametrize(
+    "changelog_format, changelog_file, insertion_flag",
+    [
+        (
+            ChangelogOutputFormat.MARKDOWN,
+            lazy_fixture(example_changelog_md.__name__),
+            lazy_fixture(default_md_changelog_insertion_flag.__name__),
+        ),
+        (
+            ChangelogOutputFormat.RESTRUCTURED_TEXT,
+            lazy_fixture(example_changelog_rst.__name__),
+            lazy_fixture(default_rst_changelog_insertion_flag.__name__),
+        ),
+    ],
+)
+@pytest.mark.parametrize(
+    "repo_result, cache_key",
+    [
+        pytest.param(
+            lazy_fixture(repo_fixture),
+            f"psr/repos/{repo_fixture}",
+            marks=pytest.mark.comprehensive,
+        )
+        for repo_fixture in [
+            # Must not have a single release/tag
+            repo_w_no_tags_conventional_commits_unmasked_initial_release.__name__,
+        ]
+    ],
+)
+def test_version_updates_changelog_wo_prev_releases_n_unmasked_initial_release(
+    repo_result: BuiltRepoResult,
+    cache_key: str,
+    cache: pytest.Cache,
+    run_cli: RunCliFn,
     update_pyproject_toml: UpdatePyprojectTomlFn,
     changelog_format: ChangelogOutputFormat,
     changelog_file: Path,
@@ -343,7 +486,7 @@ def test_version_updates_changelog_wo_prev_releases(
         str(changelog_file.name),
     )
 
-    version = "v0.1.0"
+    version = "v1.0.0"
     rst_version_header = f"{version} ({repo_build_date_str})"
     search_n_replacements = {
         ChangelogOutputFormat.MARKDOWN: (
@@ -408,7 +551,7 @@ def test_version_updates_changelog_wo_prev_releases(
     # Act
     with freeze_time(now_datetime.astimezone(timezone.utc)):
         cli_cmd = [MAIN_PROG_NAME, VERSION_SUBCMD, "--no-push", "--changelog"]
-        result = cli_runner.invoke(main, cli_cmd[1:])
+        result = run_cli(cli_cmd[1:])
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
@@ -532,7 +675,7 @@ def test_version_initializes_changelog_in_update_mode_w_no_prev_changelog(
     cache_key: str,
     get_versions_from_repo_build_def: GetVersionsFromRepoBuildDefFn,
     tag_format: str,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     update_pyproject_toml: UpdatePyprojectTomlFn,
     changelog_file: Path,
     cache: pytest.Cache,
@@ -581,7 +724,7 @@ def test_version_initializes_changelog_in_update_mode_w_no_prev_changelog(
     # Act
     with freeze_time(now_datetime.astimezone(timezone.utc)):
         cli_cmd = [MAIN_PROG_NAME, VERSION_SUBCMD, "--no-push", "--changelog"]
-        result = cli_runner.invoke(main, cli_cmd[1:])
+        result = run_cli(cli_cmd[1:])
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
@@ -611,7 +754,7 @@ def test_version_initializes_changelog_in_update_mode_w_no_prev_changelog(
 @pytest.mark.usefixtures(repo_w_trunk_only_conventional_commits.__name__)
 def test_version_maintains_changelog_in_update_mode_w_no_flag(
     changelog_file: Path,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     update_pyproject_toml: UpdatePyprojectTomlFn,
     insertion_flag: str,
 ):
@@ -641,7 +784,7 @@ def test_version_maintains_changelog_in_update_mode_w_no_flag(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, VERSION_SUBCMD, "--no-push", "--changelog"]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
@@ -687,7 +830,7 @@ def test_version_updates_changelog_w_new_version_n_filtered_commit(
     commit_type: CommitConvention,
     tag_format: str,
     update_pyproject_toml: UpdatePyprojectTomlFn,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     changelog_file: Path,
     stable_now_date: GetStableDateNowFn,
     get_commits_from_repo_build_def: GetCommitsFromRepoBuildDefFn,
@@ -740,7 +883,7 @@ def test_version_updates_changelog_w_new_version_n_filtered_commit(
     # Act
     with freeze_time(now_datetime.astimezone(timezone.utc)):
         cli_cmd = [MAIN_PROG_NAME, VERSION_SUBCMD, "--no-push", "--changelog"]
-        result = cli_runner.invoke(main, cli_cmd[1:])
+        result = run_cli(cli_cmd[1:])
 
     # Capture the new changelog content (os aware because of expected content)
     actual_content = changelog_file.read_text()
@@ -748,4 +891,6 @@ def test_version_updates_changelog_w_new_version_n_filtered_commit(
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
     assert expected_changelog_content == actual_content
-    assert expected_bump_message in actual_content
+
+    for msg_part in expected_bump_message.split("\n\n"):
+        assert msg_part.capitalize() in actual_content
