@@ -102,7 +102,8 @@ def get_repo_definition_4_git_flow_repo_w_1_release_channels(
         hvcs_domain: str = EXAMPLE_HVCS_DOMAIN,
         tag_format_str: str | None = None,
         extra_configs: dict[str, TomlSerializableTypes] | None = None,
-        mask_initial_release: bool = False,
+        mask_initial_release: bool = True,
+        ignore_merge_commits: bool = True,
     ) -> Sequence[RepoActions]:
         stable_now_datetime = stable_now_date()
         commit_timestamp_gen = (
@@ -111,7 +112,7 @@ def get_repo_definition_4_git_flow_repo_w_1_release_channels(
         )
 
         # Common static actions or components
-        changelog_file_definitons: Sequence[RepoActionWriteChangelogsDestFile] = [
+        changelog_file_definitions: Sequence[RepoActionWriteChangelogsDestFile] = [
             {
                 "path": changelog_md_file,
                 "format": ChangelogOutputFormat.MARKDOWN,
@@ -156,7 +157,7 @@ def get_repo_definition_4_git_flow_repo_w_1_release_channels(
                             tgt_branch_name=DEFAULT_BRANCH_NAME,
                         ),
                         "datetime": next(commit_timestamp_gen),
-                        "include_in_changelog": bool(commit_type == "emoji"),
+                        "include_in_changelog": not ignore_merge_commits,
                     },
                     commit_type,
                 ),
@@ -272,7 +273,7 @@ def get_repo_definition_4_git_flow_repo_w_1_release_channels(
                                     tgt_branch_name=DEV_BRANCH_NAME,
                                 ),
                                 "datetime": next(commit_timestamp_gen),
-                                "include_in_changelog": bool(commit_type == "emoji"),
+                                "include_in_changelog": not ignore_merge_commits,
                             },
                             commit_type,
                         ),
@@ -295,7 +296,7 @@ def get_repo_definition_4_git_flow_repo_w_1_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -359,7 +360,7 @@ def get_repo_definition_4_git_flow_repo_w_1_release_channels(
                                     tgt_branch_name=DEV_BRANCH_NAME,
                                 ),
                                 "datetime": next(commit_timestamp_gen),
-                                "include_in_changelog": bool(commit_type == "emoji"),
+                                "include_in_changelog": not ignore_merge_commits,
                             },
                             commit_type,
                         ),
@@ -382,7 +383,7 @@ def get_repo_definition_4_git_flow_repo_w_1_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -429,7 +430,7 @@ def get_repo_definition_4_git_flow_repo_w_1_release_channels(
                                         "\n\n",
                                         [
                                             "API: add revolutionary feature",
-                                            "BREAKING CHANGE: this is a breaking change",
+                                            "This is a breaking change",
                                         ],
                                     ),
                                     "datetime": next(commit_timestamp_gen),
@@ -464,7 +465,7 @@ def get_repo_definition_4_git_flow_repo_w_1_release_channels(
                                     tgt_branch_name=DEV_BRANCH_NAME,
                                 ),
                                 "datetime": next(commit_timestamp_gen),
-                                "include_in_changelog": bool(commit_type == "emoji"),
+                                "include_in_changelog": not ignore_merge_commits,
                             },
                             commit_type,
                         ),
@@ -487,7 +488,7 @@ def get_repo_definition_4_git_flow_repo_w_1_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -516,9 +517,9 @@ def get_repo_definition_4_git_flow_repo_w_1_release_channels(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
-                                    "conventional": "fix: correct a bug",
-                                    "emoji": ":bug: correct a bug",
-                                    "scipy": "BUG: correct a bug",
+                                    "conventional": "fix: correct a bug\n\nCloses: #123\n",
+                                    "emoji": ":bug: correct a bug\n\nCloses: #123\n",
+                                    "scipy": "BUG: correct a bug\n\nCloses: #123\n",
                                     "datetime": next(commit_timestamp_gen),
                                     "include_in_changelog": True,
                                 },
@@ -551,7 +552,7 @@ def get_repo_definition_4_git_flow_repo_w_1_release_channels(
                                     tgt_branch_name=DEV_BRANCH_NAME,
                                 ),
                                 "datetime": next(commit_timestamp_gen),
-                                "include_in_changelog": bool(commit_type == "emoji"),
+                                "include_in_changelog": not ignore_merge_commits,
                             },
                             commit_type,
                         ),
@@ -574,7 +575,7 @@ def get_repo_definition_4_git_flow_repo_w_1_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -638,7 +639,7 @@ def get_repo_definition_4_git_flow_repo_w_1_release_channels(
                                     tgt_branch_name=DEV_BRANCH_NAME,
                                 ),
                                 "datetime": next(commit_timestamp_gen),
-                                "include_in_changelog": bool(commit_type == "emoji"),
+                                "include_in_changelog": not ignore_merge_commits,
                             },
                             commit_type,
                         ),
@@ -661,7 +662,7 @@ def get_repo_definition_4_git_flow_repo_w_1_release_channels(
                                 {
                                     "conventional": "feat(cli): add new config cli command",
                                     "emoji": ":sparkles: (cli) add new config cli command",
-                                    "scipy": "ENH(cli): add new config cli command",
+                                    "scipy": "ENH: cli: add new config cli command",
                                     "datetime": next(commit_timestamp_gen),
                                     "include_in_changelog": True,
                                 },
@@ -694,7 +695,7 @@ def get_repo_definition_4_git_flow_repo_w_1_release_channels(
                                     tgt_branch_name=DEV_BRANCH_NAME,
                                 ),
                                 "datetime": next(commit_timestamp_gen),
-                                "include_in_changelog": bool(commit_type == "emoji"),
+                                "include_in_changelog": not ignore_merge_commits,
                             },
                             commit_type,
                         ),
@@ -717,7 +718,7 @@ def get_repo_definition_4_git_flow_repo_w_1_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
