@@ -104,7 +104,8 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
         hvcs_domain: str = EXAMPLE_HVCS_DOMAIN,
         tag_format_str: str | None = None,
         extra_configs: dict[str, TomlSerializableTypes] | None = None,
-        mask_initial_release: bool = False,
+        mask_initial_release: bool = True,
+        ignore_merge_commits: bool = True,
     ) -> Sequence[RepoActions]:
         stable_now_datetime = stable_now_date()
         commit_timestamp_gen = (
@@ -113,7 +114,7 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
         )
 
         # Common static actions or components
-        changelog_file_definitons: Sequence[RepoActionWriteChangelogsDestFile] = [
+        changelog_file_definitions: Sequence[RepoActionWriteChangelogsDestFile] = [
             {
                 "path": changelog_md_file,
                 "format": ChangelogOutputFormat.MARKDOWN,
@@ -158,7 +159,7 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
                             tgt_branch_name=DEFAULT_BRANCH_NAME,
                         ),
                         "datetime": next(commit_timestamp_gen),
-                        "include_in_changelog": bool(commit_type == "emoji"),
+                        "include_in_changelog": not ignore_merge_commits,
                     },
                     commit_type,
                 ),
@@ -286,7 +287,7 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
                                     tgt_branch_name=DEV_BRANCH_NAME,
                                 ),
                                 "datetime": next(commit_timestamp_gen),
-                                "include_in_changelog": bool(commit_type == "emoji"),
+                                "include_in_changelog": not ignore_merge_commits,
                             },
                             commit_type,
                         ),
@@ -309,7 +310,7 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -359,7 +360,7 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -396,7 +397,7 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
                                         "\n\n",
                                         [
                                             "API: add revolutionary feature",
-                                            "BREAKING CHANGE: this is a breaking change",
+                                            "This is a breaking change",
                                         ],
                                     ),
                                     "datetime": next(commit_timestamp_gen),
@@ -417,7 +418,7 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -454,7 +455,7 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
                                     tgt_branch_name=DEV_BRANCH_NAME,
                                 ),
                                 "datetime": next(commit_timestamp_gen),
-                                "include_in_changelog": bool(commit_type == "emoji"),
+                                "include_in_changelog": not ignore_merge_commits,
                             },
                             commit_type,
                         ),
@@ -470,7 +471,7 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -500,7 +501,7 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -531,7 +532,7 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
                                 {
                                     "conventional": "feat(cli): add new config cli command",
                                     "emoji": ":sparkles: (cli) add new config cli command",
-                                    "scipy": "ENH(cli): add new config cli command",
+                                    "scipy": "ENH:cli: add new config cli command",
                                     "datetime": next(commit_timestamp_gen),
                                     "include_in_changelog": True,
                                 },
@@ -550,7 +551,7 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -571,7 +572,7 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
                                 {
                                     "conventional": "feat(config): add new config option",
                                     "emoji": ":sparkles: (config) add new config option",
-                                    "scipy": "ENH(config): add new config option",
+                                    "scipy": "ENH: config: add new config option",
                                     "datetime": next(commit_timestamp_gen),
                                     "include_in_changelog": True,
                                 },
@@ -590,7 +591,7 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -627,7 +628,7 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
                                     tgt_branch_name=DEV_BRANCH_NAME,
                                 ),
                                 "datetime": next(commit_timestamp_gen),
-                                "include_in_changelog": bool(commit_type == "emoji"),
+                                "include_in_changelog": not ignore_merge_commits,
                             },
                             commit_type,
                         ),
@@ -650,7 +651,7 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
                                 {
                                     "conventional": "fix(cli): fix config cli command",
                                     "emoji": ":bug: (cli) fix config cli command",
-                                    "scipy": "BUG(cli): fix config cli command",
+                                    "scipy": "BUG:cli: fix config cli command",
                                     "datetime": next(commit_timestamp_gen),
                                     "include_in_changelog": True,
                                 },
@@ -683,7 +684,7 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
                                     tgt_branch_name=DEV_BRANCH_NAME,
                                 ),
                                 "datetime": next(commit_timestamp_gen),
-                                "include_in_changelog": bool(commit_type == "emoji"),
+                                "include_in_changelog": not ignore_merge_commits,
                             },
                             commit_type,
                         ),
@@ -699,7 +700,7 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -727,9 +728,9 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
-                                    "conventional": "fix(config): fix config option",
-                                    "emoji": ":bug: (config) fix config option",
-                                    "scipy": "BUG(config): fix config option",
+                                    "conventional": "fix(config): fix config option\n\nImplements: #123\n",
+                                    "emoji": ":bug: (config) fix config option\n\nImplements: #123\n",
+                                    "scipy": "BUG: config: fix config option\n\nImplements: #123\n",
                                     "datetime": next(commit_timestamp_gen),
                                     "include_in_changelog": True,
                                 },
@@ -762,7 +763,7 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
                                     tgt_branch_name=DEV_BRANCH_NAME,
                                 ),
                                 "datetime": next(commit_timestamp_gen),
-                                "include_in_changelog": bool(commit_type == "emoji"),
+                                "include_in_changelog": not ignore_merge_commits,
                             },
                             commit_type,
                         ),
@@ -778,7 +779,7 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -808,7 +809,7 @@ def get_repo_definition_4_git_flow_repo_w_3_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
