@@ -114,7 +114,8 @@ def get_repo_definition_4_git_flow_repo_w_4_release_channels(
         hvcs_domain: str = EXAMPLE_HVCS_DOMAIN,
         tag_format_str: str | None = None,
         extra_configs: dict[str, TomlSerializableTypes] | None = None,
-        mask_initial_release: bool = False,
+        mask_initial_release: bool = True,
+        ignore_merge_commits: bool = True,
     ) -> Sequence[RepoActions]:
         stable_now_datetime = stable_now_date()
         commit_timestamp_gen = (
@@ -123,7 +124,7 @@ def get_repo_definition_4_git_flow_repo_w_4_release_channels(
         )
 
         # Common static actions or components
-        changelog_file_definitons: Sequence[RepoActionWriteChangelogsDestFile] = [
+        changelog_file_definitions: Sequence[RepoActionWriteChangelogsDestFile] = [
             {
                 "path": changelog_md_file,
                 "format": ChangelogOutputFormat.MARKDOWN,
@@ -182,7 +183,7 @@ def get_repo_definition_4_git_flow_repo_w_4_release_channels(
                             tgt_branch_name=BETA_BRANCH_NAME,
                         ),
                         "datetime": next(commit_timestamp_gen),
-                        "include_in_changelog": bool(commit_type == "emoji"),
+                        "include_in_changelog": not ignore_merge_commits,
                     },
                     commit_type,
                 ),
@@ -209,7 +210,7 @@ def get_repo_definition_4_git_flow_repo_w_4_release_channels(
                             tgt_branch_name=DEFAULT_BRANCH_NAME,
                         ),
                         "datetime": next(commit_timestamp_gen),
-                        "include_in_changelog": bool(commit_type == "emoji"),
+                        "include_in_changelog": not ignore_merge_commits,
                     },
                     commit_type,
                 ),
@@ -351,7 +352,7 @@ def get_repo_definition_4_git_flow_repo_w_4_release_channels(
                                     tgt_branch_name=DEV_BRANCH_NAME,
                                 ),
                                 "datetime": next(commit_timestamp_gen),
-                                "include_in_changelog": bool(commit_type == "emoji"),
+                                "include_in_changelog": not ignore_merge_commits,
                             },
                             commit_type,
                         ),
@@ -381,7 +382,7 @@ def get_repo_definition_4_git_flow_repo_w_4_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -411,9 +412,9 @@ def get_repo_definition_4_git_flow_repo_w_4_release_channels(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
-                                    "conventional": "fix(cli): fix config cli command",
-                                    "emoji": ":bug: (cli) fix config cli command",
-                                    "scipy": "BUG(cli): fix config cli command",
+                                    "conventional": "fix(cli): fix config cli command\n\nCloses: #123\n",
+                                    "emoji": ":bug: (cli) fix config cli command\n\nCloses: #123\n",
+                                    "scipy": "BUG:cli: fix config cli command\n\nCloses: #123\n",
                                     "datetime": next(commit_timestamp_gen),
                                     "include_in_changelog": True,
                                 },
@@ -446,7 +447,7 @@ def get_repo_definition_4_git_flow_repo_w_4_release_channels(
                                     tgt_branch_name=DEV_BRANCH_NAME,
                                 ),
                                 "datetime": next(commit_timestamp_gen),
-                                "include_in_changelog": bool(commit_type == "emoji"),
+                                "include_in_changelog": not ignore_merge_commits,
                             },
                             commit_type,
                         ),
@@ -462,7 +463,7 @@ def get_repo_definition_4_git_flow_repo_w_4_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -492,7 +493,7 @@ def get_repo_definition_4_git_flow_repo_w_4_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -523,7 +524,7 @@ def get_repo_definition_4_git_flow_repo_w_4_release_channels(
                                 {
                                     "conventional": "fix(config): fix config option",
                                     "emoji": ":bug: (config) fix config option",
-                                    "scipy": "BUG(config): fix config option",
+                                    "scipy": "BUG: config: fix config option",
                                     "datetime": next(commit_timestamp_gen),
                                     "include_in_changelog": True,
                                 },
@@ -556,7 +557,7 @@ def get_repo_definition_4_git_flow_repo_w_4_release_channels(
                                     tgt_branch_name=DEV_BRANCH_NAME,
                                 ),
                                 "datetime": next(commit_timestamp_gen),
-                                "include_in_changelog": bool(commit_type == "emoji"),
+                                "include_in_changelog": not ignore_merge_commits,
                             },
                             commit_type,
                         ),
@@ -572,7 +573,7 @@ def get_repo_definition_4_git_flow_repo_w_4_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -602,7 +603,7 @@ def get_repo_definition_4_git_flow_repo_w_4_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -634,7 +635,7 @@ def get_repo_definition_4_git_flow_repo_w_4_release_channels(
                                 {
                                     "conventional": "feat(feat-2): add another primary feature",
                                     "emoji": ":sparkles: (feat-2) add another primary feature",
-                                    "scipy": "ENH(feat-2): add another primary feature",
+                                    "scipy": "ENH: feat-2: add another primary feature",
                                     "datetime": next(commit_timestamp_gen),
                                     "include_in_changelog": True,
                                 },
@@ -653,7 +654,7 @@ def get_repo_definition_4_git_flow_repo_w_4_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -690,7 +691,7 @@ def get_repo_definition_4_git_flow_repo_w_4_release_channels(
                                     tgt_branch_name=DEV_BRANCH_NAME,
                                 ),
                                 "datetime": next(commit_timestamp_gen),
-                                "include_in_changelog": bool(commit_type == "emoji"),
+                                "include_in_changelog": not ignore_merge_commits,
                             },
                             commit_type,
                         ),
@@ -706,7 +707,7 @@ def get_repo_definition_4_git_flow_repo_w_4_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -736,7 +737,7 @@ def get_repo_definition_4_git_flow_repo_w_4_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -766,7 +767,7 @@ def get_repo_definition_4_git_flow_repo_w_4_release_channels(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
